pypotrace documentation — potrace v0.1 documentation

### Navigation

- index
- modules |
- next |
- potrace v0.1 documentation »

# pypotrace documentation

pypotrace are Python bindings for potrace, an utility to transform bitmap images into vector images.

Contents:

- Tutorial
- `potrace` – API reference
  - Bitmap objects
  - Path objects
  - Curve objects

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- potrace v0.1 documentation »